@@ -75,7 +75,7 @@ VLC_BOOTSTRAP_ARGS="\
     --disable-caca \
     --disable-gettext \
     --disable-mpcdec \
-    --disable-upnp \
+    --enable-upnp \
     --disable-gme \
     --disable-tremor \
     --enable-vorbis \
@@ -121,7 +121,7 @@ VLC_CONFIGURE_ARGS="\
     --disable-decklink \
     --disable-libva \
     --disable-dv1394 \
-    --disable-mod \
+    --enable-mod \
     --disable-sid \
     --disable-gme \
     --disable-tremor \
@@ -155,7 +155,7 @@ VLC_CONFIGURE_ARGS="\
     --enable-vorbis \
     --disable-faad \
     --disable-x264 \
-    --disable-schroedinger --disable-dirac \
+    --disable-schroedinger \
 "
 
 ########################
@@ -206,7 +206,6 @@ VLC_MODULE_BLACKLIST="
     remoteosd
     magnify
     gradient
-    .*tospdif
     dtstofloat32
     logger
     visual
@@ -485,7 +484,6 @@ mkdir -p $VLC_BUILD_DIR && cd $VLC_BUILD_DIR
 # CONFIGURE #
 #############
 
-if [ ! -e ./config.h ]; then
 if [ "${CHROME_OS}" = "1" ];then
     # chrome OS doesn't have eventfd
     export ac_cv_func_eventfd=no
@@ -502,6 +500,7 @@ if [ ${ANDROID_ABI} = "x86" -a ${ANDROID_API} != "android-21" ] ; then
     # intel devices has nanf. Assume they don't have it.
     export ac_cv_lib_m_nanf=no
 fi
+if [ ! -e ./config.h -o "$RELEASE" = 1 ]; then
 CPPFLAGS="$CPPFLAGS" \
 CFLAGS="$CFLAGS ${VLC_EXTRA_CFLAGS} ${EXTRA_CFLAGS}" \
 CXXFLAGS="$CFLAGS" \
@@ -602,14 +601,15 @@ VLC_CONTRIB="$VLC_SRC_DIR/contrib/$TARGET_TUPLE"
 
 if [ "${CHROME_OS}" != "1" ];then
     if [ "${HAVE_64}" != 1 ];then
-    # Can't link with 32bits symbols.
-    # Not a problem since MediaCodec should work on 64bits devices (android-21)
-    LIBIOMX_LIBS="libiomx.14 libiomx.13 libiomx.10"
+        # Can't link with 32bits symbols.
+        # Not a problem since MediaCodec should work on 64bits devices (android-21)
+        LIBIOMX_LIBS="libiomx.14 libiomx.13 libiomx.10"
+        LIBANW_LIBS="libanw.10 libanw.13 libanw.14 libanw.18"
     fi
     # (after android Jelly Bean, we prefer to use MediaCodec instead of iomx)
     #LIBIOMX_LIBS="${LIBIOMX_LIBS }libiomx.19 libiomx.18"
 
-    LIBANW_LIBS="libanw.10 libanw.13 libanw.14 libanw.18 libanw.21"
+    LIBANW_LIBS="$LIBANW_LIBS libanw.21"
 fi
 
 echo "Building NDK"
