@@ -50,7 +50,7 @@ public class MediaDatabase {
 
     private SQLiteDatabase mDb;
     private static final String DB_NAME = "vlc_database";
-    private static final int DB_VERSION = 17;
+    private static final int DB_VERSION = 18;
     private static final int CHUNK_SIZE = 50;
 
     private static final String DIR_TABLE_NAME = "directories_table";
@@ -96,6 +96,7 @@ public class MediaDatabase {
 
     private static final String NETWORK_FAV_TABLE_NAME = "fav_table";
     private static final String NETWORK_FAV_URI = "uri";
+    private static final String NETWORK_FAV_TITLE = "title";
 
     public enum mediaColumn {
         MEDIA_TABLE_NAME, MEDIA_PATH, MEDIA_TIME, MEDIA_LENGTH,
@@ -162,6 +163,8 @@ public class MediaDatabase {
         public void dropMediaTableQuery(SQLiteDatabase db) {
             String query = "DROP TABLE " + MEDIA_TABLE_NAME + ";";
             db.execSQL(query);
+            query = "DROP TABLE " + MEDIA_VIRTUAL_TABLE_NAME + ";";
+            db.execSQL(query);
         }
 
         public void createMediaTableQuery(SQLiteDatabase db) {
@@ -187,7 +190,7 @@ public class MediaDatabase {
                     + ");";
             db.execSQL(query);
             db.execSQL("PRAGMA recursive_triggers='ON'"); //Needed for delete trigger
-            query = "CREATE VIRTUAL TABLE "
+            query = "CREATE VIRTUAL TABLE IF NOT EXISTS "
                     + MEDIA_VIRTUAL_TABLE_NAME + " USING FTS3 ("
                     + MEDIA_LOCATION + ", "
                     + MEDIA_TITLE + ", "
@@ -251,7 +254,9 @@ public class MediaDatabase {
         private void createNetworkFavTableQuery(SQLiteDatabase db) {
             String createMrlTableQuery = "CREATE TABLE IF NOT EXISTS " +
                     NETWORK_FAV_TABLE_NAME + " (" +
-                    MRL_URI + " TEXT PRIMARY KEY NOT NULL);";
+                    NETWORK_FAV_URI + " TEXT PRIMARY KEY NOT NULL, " +
+                    NETWORK_FAV_TITLE + " TEXT NOT NULL" +
+                    ");";
             db.execSQL(createMrlTableQuery);
         }
 
@@ -311,9 +316,14 @@ public class MediaDatabase {
                 case 13:
                     createNetworkFavTableQuery(db);
                     break;
-                    case 17:
-                        dropMRLTableQuery(db);
-                        createMRLTableQuery(db);
+                case 17:
+                    dropMRLTableQuery(db);
+                    createMRLTableQuery(db);
+                    break;
+                case 18:
+                    dropNetworkFavTableQuery(db);
+                    createNetworkFavTableQuery(db);
+                    break;
                 default:
                     break;
                 }
@@ -1001,9 +1011,10 @@ public class MediaDatabase {
     }
 
 
-    public synchronized void addNetworkFavItem(String mrl) {
+    public synchronized void addNetworkFavItem(String mrl, String title) {
         ContentValues values = new ContentValues();
         values.put(NETWORK_FAV_URI, Uri.encode(mrl));
+        values.put(NETWORK_FAV_TITLE, Uri.encode(title));
         mDb.replace(NETWORK_FAV_TABLE_NAME, null, values);
     }
 
@@ -1018,15 +1029,18 @@ public class MediaDatabase {
         return exists;
     }
 
-    public synchronized ArrayList<String> getAllNetworkFav() {
-        ArrayList<String> favs = new ArrayList<String>();
+    public synchronized ArrayList<MediaWrapper> getAllNetworkFav() {
+        ArrayList<MediaWrapper> favs = new ArrayList<MediaWrapper>();
 
+        MediaWrapper mw;
         Cursor cursor = mDb.query(NETWORK_FAV_TABLE_NAME,
-                new String[] { NETWORK_FAV_URI },
+                new String[] { NETWORK_FAV_URI , NETWORK_FAV_TITLE},
                 null, null, null, null, null);
 
         while (cursor.moveToNext()) {
-            favs.add(Uri.decode(cursor.getString(0)));
+            mw = new MediaWrapper(Uri.decode(cursor.getString(0)));
+            mw.setTitle(Uri.decode(cursor.getString(1)));
+            favs.add(mw);
         }
         cursor.close();
 
