@@ -547,6 +547,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             mSearchView = (SearchView) MenuItemCompat.getActionView(menu.findItem(R.id.ml_menu_search));
             mSearchView.setSearchableInfo(searchManager.getSearchableInfo(getComponentName()));
             mSearchView.setOnQueryTextListener(this);
+            mSearchView.setQueryHint(getString(R.string.search_hint));
             mSearchView.setSuggestionsAdapter(new SearchSuggestionsAdapter(this, null));
         } else
             menu.findItem(R.id.ml_menu_search).setVisible(false);
@@ -578,7 +579,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         }
         else
             menu.findItem(R.id.ml_menu_save).setVisible(false);
-        menu.findItem(R.id.ml_menu_clean).setVisible(SidebarEntry.ID_MRL.equals(mCurrentFragment));
+        if (current instanceof MRLPanelFragment)
+            menu.findItem(R.id.ml_menu_clean).setVisible(!((MRLPanelFragment) current).isEmpty());
         menu.findItem(R.id.ml_menu_last_playlist).setVisible(SidebarEntry.ID_AUDIO.equals(mCurrentFragment));
 
 
@@ -825,10 +827,12 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
     @Override
     public boolean onQueryTextChange(String newText) {
-        if (newText.length() < 3)
+        if (newText.length() < 3) {
+            mSearchView.getSuggestionsAdapter().swapCursor(null);
             return false;
+        }
         Cursor cursor = MediaDatabase.getInstance().queryMedia(newText);
-        mSearchView.getSuggestionsAdapter().changeCursor(cursor);
+        mSearchView.getSuggestionsAdapter().swapCursor(cursor);
         return true;
     }
 
