@@ -141,7 +141,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         mGridView = (GridView) v.findViewById(android.R.id.list);
         mSwipeRefreshLayout = (SwipeRefreshLayout) v.findViewById(R.id.swipeLayout);
 
-        mSwipeRefreshLayout.setColorSchemeResources(R.color.darkerorange);
+        mSwipeRefreshLayout.setColorSchemeResources(R.color.orange700);
         mSwipeRefreshLayout.setOnRefreshListener(this);
 
         mGridView.setOnScrollListener(new AbsListView.OnScrollListener() {
@@ -405,6 +405,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
     private void focusHelper(boolean idIsEmpty) {
         View parent = getView();
         MainActivity main = (MainActivity)getActivity();
+        if (main == null)
+            return;
         main.setMenuFocusDown(idIsEmpty, android.R.id.list);
         main.setSearchAsFocusDown(idIsEmpty, parent,
                     android.R.id.list);
@@ -420,7 +422,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         else
             Log.w(TAG, "Can't generate thumbnails, the thumbnailer is missing");
 
-        mVideoAdapter.setNotifyOnChange(false);
+        mVideoAdapter.setNotifyOnChange(true);
         mVideoAdapter.clear();
 
         if (itemList.size() > 0) {
