@@ -36,6 +36,7 @@ import android.content.Context;
 import android.content.res.ColorStateList;
 import android.graphics.Bitmap;
 import android.support.annotation.Nullable;
+import android.support.v7.widget.CardView;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.View.OnClickListener;
@@ -148,6 +149,7 @@ public class VideoListAdapter extends ArrayAdapter<MediaWrapper>
                 v = inflater.inflate(R.layout.video_grid_card, parent, false);
             else
                 v = inflater.inflate(R.layout.video_list_card, parent, false);
+            ((CardView)v).setPreventCornerOverlap(false);
 
             holder = new ViewHolder();
             holder.thumbnail = (ImageView) v.findViewById(R.id.ml_item_thumbnail);
@@ -166,6 +168,9 @@ public class VideoListAdapter extends ArrayAdapter<MediaWrapper>
             holder = (ViewHolder) v.getTag();
         }
 
+        if (position >= getCount() || position < 0)
+            return v;
+
         holder.more.setOnClickListener(new OnClickListener() {
             @Override
             public void onClick(View v) {
@@ -259,13 +264,4 @@ public class VideoListAdapter extends ArrayAdapter<MediaWrapper>
     public boolean isListMode() {
         return mListMode;
     }
-
-    @Override
-    @Nullable
-    public MediaWrapper getItem(int position) {
-        if (position < getCount() && position >= 0)
-            return super.getItem(position);
-        else
-            return null;
-    }
 }
